# Formal Models of Reflective Equilibrium - Technical Report


Technical report for the SNF-DFG project ["Formal Models of Reflective Equilibrium - How Far Does Reflective Equilibrium Take Us?"](https://www.philosophie.unibe.ch/forschung/forschungsprojekte/how_far_does_reflective_equilibrium_take_us/project/index_ger.html).


The repository has the following structure:

+ `data`: Data on which the data analysis is based on.
+ `notebooks`: [Jupyter notebooks](https://jupyter.org/) to reproduce the data analysis.
+ `report`: [Quarto](https://quarto.org/) source files for this report.
+ `output`: Quarto generated output.


---
Shield: [![CC BY 4.0][cc-by-shield]][cc-by]

This work is licensed under a
[Creative Commons Attribution 4.0 International License][cc-by].

[![CC BY 4.0][cc-by-image]][cc-by]

[cc-by]: http://creativecommons.org/licenses/by/4.0/
[cc-by-image]: https://i.creativecommons.org/l/by/4.0/88x31.png
[cc-by-shield]: https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg
